impl_extract_for_tuple

Macro impl_extract_for_tuple 

macro_rules! impl_extract_for_tuple {
    ($(($E:ident, $e:ident)),*) => { ... };
}
Direct Extract impls for tuples. All elements must extract to the same Target, which is the natural semantics of a single Target associated type.