macro_rules! lagged {
($lag_ratio:expr; $($animation:expr),* $(,)?) => { ... };
}Expand description
Construct an AnimLagged with a stagger ratio, pushing each animation in order.
macro_rules! lagged {
($lag_ratio:expr; $($animation:expr),* $(,)?) => { ... };
}Construct an AnimLagged with a stagger ratio, pushing each animation in order.