RanimScene

Struct RanimScene 

pub struct RanimScene {
    pub(crate) timelines: Vec<Timeline>,
    pub(crate) time_marks: Vec<(f64, TimeMark)>,
}
The main struct that offers the ranim’s API, and encodes animations

Fields

timelines: Vec<Timeline>time_marks: Vec<(f64, TimeMark)>

Implementations

Source

impl RanimScene

pub fn seal(self) -> SealedRanimScene

Seals the scene to SealedRanimScene.

pub fn new() -> Self

Create a new RanimScene

pub fn insert_empty(&mut self) -> TimelineId

Insert an empty timeline.

pub fn insert_empty_at(&mut self, sec: f64) -> TimelineId

Insert an empty timeline and forward it to the given sec.

pub fn insert<T: Extract<Target = CoreItem> + Clone + 'static>( &mut self, item: T, ) -> TimelineId

Insert a timeline at 0.0 sec and play StaticAnim::show on it.

pub fn insert_at<T: Extract<Target = CoreItem> + Clone + 'static>( &mut self, item: T, sec: f64, ) -> TimelineId

Insert a timeline at the given sec and play StaticAnim::show on it.

pub fn insert_with(&mut self, f: impl FnMut(&mut Timeline)) -> TimelineId

Insert a empty timeline and call f on it.

pub fn timelines(&self) -> &[Timeline]

Get reference of all timelines

pub fn timelines_mut(&mut self) -> &mut [Timeline]

Get mutable reference of all timelines

pub fn timeline<'a, T: TimelineIndex<'a>>(&'a self, index: T) -> T::RefOutput

Get the reference of timeline(s) by the TimelineIndex.

pub fn timeline_mut<'a, T: TimelineIndex<'a>>( &'a mut self, index: T, ) -> T::MutOutput

Get the mutable reference of timeline(s) by the TimelineIndex.

pub fn insert_time_mark(&mut self, sec: f64, time_mark: TimeMark)

Inserts an TimeMark