SealedRanimScene

Struct SealedRanimScene 

pub struct SealedRanimScene {
    pub(crate) total_secs: f64,
    pub(crate) timelines: Vec<Timeline>,
    pub(crate) time_marks: Vec<(f64, TimeMark)>,
}
The sealed RanimScene.

the timelines and time marks cannot be modified after sealed. And once the RanimScene is sealed, it can be used for evaluating.

Fields

total_secs: f64timelines: Vec<Timeline>time_marks: Vec<(f64, TimeMark)>

Implementations

Source

impl SealedRanimScene

pub fn total_secs(&self) -> f64

Get the total seconds of the SealedRanimScene.

pub fn time_marks(&self) -> &[(f64, TimeMark)]

Get time marks

pub fn timelines_iter(&self) -> impl Iterator<Item = &Timeline>

Get the iterator of timelines

pub fn timelines_cnt(&self) -> usize

Get the count of timelines

pub fn get_timeline_infos(&self) -> Vec<TimelineInfo>

Get timeline infos.

pub fn eval_at_sec( &self, target_sec: f64, ) -> impl Iterator<Item = ((usize, usize), CoreItem)>

Eval primitives

pub fn eval_at_alpha( &self, alpha: f64, ) -> impl Iterator<Item = ((usize, usize), CoreItem)>

Eval primitives