pub struct SealedRanimScene {
pub(crate) total_secs: f64,
pub(crate) timelines: Vec<Timeline>,
pub(crate) time_marks: Vec<(f64, TimeMark)>,
}Expand description
The sealed RanimScene.
the timelines and time marks cannot be modified after sealed. And
once the RanimScene is sealed, it can be used for evaluating.
Fields
total_secs: f64timelines: Vec<Timeline>time_marks: Vec<(f64, TimeMark)>Implementations
Sourceimpl SealedRanimScene
impl SealedRanimScene
Sourcepub fn total_secs(&self) -> f64
pub fn total_secs(&self) -> f64
Get the total seconds of the SealedRanimScene.
Sourcepub fn time_marks(&self) -> &[(f64, TimeMark)]
pub fn time_marks(&self) -> &[(f64, TimeMark)]
Get time marks
Sourcepub fn timelines_iter(&self) -> impl Iterator<Item = &Timeline>
pub fn timelines_iter(&self) -> impl Iterator<Item = &Timeline>
Get the iterator of timelines
Sourcepub fn timelines_cnt(&self) -> usize
pub fn timelines_cnt(&self) -> usize
Get the count of timelines
Sourcepub fn get_timeline_infos(&self) -> Vec<TimelineInfo>
pub fn get_timeline_infos(&self) -> Vec<TimelineInfo>
Get timeline infos.